Struct VirtioGpuResourceCreate2d
Source #[repr(C)]
struct VirtioGpuResourceCreate2d {
hdr: VirtioGpuCtrlHdr,
resource_id: u32,
format: u32,
width: u32,
height: u32,
}
VirtIO GPU resource create 2D
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.