Struct VirtioGpuTransferToHost2d
Source #[repr(C)]
struct VirtioGpuTransferToHost2d {
hdr: VirtioGpuCtrlHdr,
r: VirtioGpuRect,
offset: u64,
resource_id: u32,
padding: u32,
}
VirtIO GPU transfer to host 2D
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.